is_facing_front_text

Function is_facing_front_text 

pub fn is_facing_front_text(
    state: BlockStateId,
    pos: BlockPos,
    player: &Player,
) -> bool
Calculates whether the player is facing the front of a sign.

Uses the sign’s rotation (from block state) and the player’s position relative to the sign to determine which side they’re looking at.